@@ -74,6 +74,11 @@ GList*                      gda_connection_list_datasources  (Gda_Connection* cn
 gint                        gda_connection_begin_transaction (Gda_Connection* cnc);
 gint                        gda_connection_commit_transaction (Gda_Connection* cnc);
 gint                        gda_connection_rollback_transaction (Gda_Connection* cnc);
+Gda_Recordset*              gda_connection_execute           (Gda_Connection* cnc, gchar* txt, gulong* reccount, gulong flags);
+gint                        gda_connection_start_logging     (Gda_Connection* cnc, gchar* filename);
+gint                        gda_connection_stop_logging      (Gda_Connection* cnc);
+gchar*                      gda_connection_create_recordset  (Gda_Connection* cnc, Gda_Recordset* rs);
+
 
 
 /**
