@@ -29,7 +29,10 @@ typedef struct _Gda_Server
   gchar* repo_id;
 }Gda_Server;
 
-Gda_Server*                 gda_server_new                   (void);
-void                        gda_server_free                  (Gda_Server*);
-
+Gda_Server*                gda_server_new                   (void);
+Gda_Server*                gda_server_copy                  (Gda_Server*);
+void                       gda_server_free                  (Gda_Server*);
+GList*                     gda_server_list                  (void);
+GList*                     gda_list_datasources             (void);
+GList*                     gda_list_datasources_for_provider(gchar* provider);
 #endif
