@@ -38,8 +38,32 @@ gda_mysql_error_free(Gda_MYSQL_Error* e)
     g_free(e->sqlstate);
   if (e->native)
     g_free(e->native);
+  if (e->helpfile)
+    g_free(e->helpfile);
+  if (e->helpctxt)
+    g_free(e->helpctxt);
   g_free(e);
 }
 
-      
+
+void
+gda_mysql_error_make(Gda_MYSQL_Connection* cnc, gchar* where)
+{
+  Gda_MYSQL_Error* error = gda_mysql_error_new();
+  gchar bfr[128];
+
+  g_warning("Error at '%s': ", where);
+  g_snprintf(bfr, sizeof(bfr), "S%d", mysql_errno(cnc->mysql));
+  error->description = g_strdup(mysql_error(cnc->mysql));
+  error->source = g_strdup("[MYSQL]");
+  error->helpfile = 0;
+  error->helpctxt = 0;
+  error->sqlstate = g_strdup(bfr);
+  error->native = g_strdup(error->description);
+  cnc->errors = g_list_append(cnc->errors, error);
+  g_warning("error->description = '%s'\n", error->description);
+  g_warning("   sqlstate = '%s'\n", error->sqlstate);
+  
+}
+
 		    
