@@ -20,14 +20,24 @@
 #define __GDA_MYSQL_TYPES_H__
 
 #include <glib.h>
+#include "gda.h"
 #include <mysql/mysql.h>
+#include <mysql/mysql_com.h>
 
+struct _Gda_MYSQL_Recordset;
+
+typedef MYSQL_ROW (*Gda_MYSQL_fix_fields)(struct _Gda_MYSQL_Recordset*,  MYSQL_ROW row);
+					  
 
 typedef struct _Gda_MYSQL_Recordset
 {
-  MYSQL*        mysql;
-  MYSQL_RES*    mysql_res;
-  GList*        fields;
+  MYSQL*               mysql;
+  MYSQL_RES*           mysql_res;
+  GList*               fields;
+  gint*                order;
+  gint                 order_count;
+  Gda_MYSQL_fix_fields fix_fields;
+  MYSQL_ROW            array;
 }Gda_MYSQL_Recordset;
 
 typedef struct _Gda_MYSQL_Connection
@@ -40,7 +50,7 @@ typedef struct _Gda_MYSQL_Connection
   gchar* unix_socket;
   gchar* flags;
   MYSQL* mysql;
-  
+  GList* errors;
 }Gda_MYSQL_Connection;
 
 typedef struct _Gda_MYSQL_Command
@@ -56,12 +66,13 @@ typedef struct _Gda_MYSQL_Parameter
 
 typedef struct _Gda_MYSQL_Field
 {
-  gchar* name;
-  gchar* def;
-  gint   native_type;
-  gint   max_length;
-  gint   decimals;
-  guint  flags;
+  gchar*     name;
+  gchar*     def;
+  enum enum_field_types      native_type;
+  gint       defined_length;
+  gint       decimals;
+  guint      flags;
+  GDA_Value* value;
 } Gda_MYSQL_Field;
 
 
@@ -74,6 +85,8 @@ typedef struct _Gda_MYSQL_Error
   gchar* source;
   gchar* sqlstate;
   gchar* native;
+  gchar* helpfile;
+  gchar* helpctxt;
 }Gda_MYSQL_Error;
 
 #endif
