@@ -33,15 +33,7 @@ void                  gda_odbc_recset_free        (Gda_ODBC_Recordset*);
 gint                  gda_odbc_recset_close       (Gda_ODBC_Recordset* rs);
 gint                  gda_odbc_recset_move_next   (Gda_ODBC_Recordset* rs);
 gint                  gda_odbc_recset_move_prev   (Gda_ODBC_Recordset* rs);
-/*
-  Development & Debugging
-*/
-void                  gda_odbc_recset_dump        (Gda_ODBC_Recordset* rs);
-						     
-
-/*
- Internal utilities
-*/
-Gda_ODBC_Recordset* gda_odbc_describe_recset      (Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e);
+gint                  gda_odbc_recset_allocmem    (Gda_ODBC_Recordset* rec);
+Gda_ODBC_Recordset*   gda_odbc_describe_recset    (Gda_ODBC_Recordset* rec);
 
 #endif
