@@ -2,9 +2,6 @@
 #include <orb/orbit.h>
 #include <libgnorba/gnorba.h>
 
-CORBA_Object connection_factory__create  (PortableServer_POA poa,   gpointer *impl_ptr,  CORBA_Environment *ev);
-void         connection_factory__destroy (PortableServer_POA poa,   gpointer impl_ptr,   CORBA_Environment *ev);
-
 static CORBA_Object create_factory (PortableServer_POA poa, const gchar* goad_id, const gchar** params,
 				    gpointer* impl_ptr, CORBA_Environment* ev);
 static void         destroy_factory(PortableServer_POA poa, const gchar* goad_id, gpointer impl_ptr,
@@ -18,12 +15,12 @@ static const gchar* repo_id = "IDL:gda/connection_factory:1.0";
 static CORBA_Object create_factory(PortableServer_POA poa, const gchar* goad_id, const gchar** params, gpointer*
 				   impl_ptr, CORBA_Environment* ev)
 {
-  return connection_factory__create(poa, impl_ptr, ev);
+  return impl_GDA_ConnectionFactory__create(poa, ev);
 }
 
 static void destroy_factory(PortableServer_POA poa, const gchar* goad_id, gpointer impl_ptr, CORBA_Environment* ev)
 {
-  connection_factory__destroy (poa, impl_ptr, ev);
+  impl_GDA_ConnectionFactory__destroy (poa, ev);
 }
 
 
