@@ -115,24 +115,30 @@ main(int argc, char* argv[])
     }
   position = gda_recordset_move(rs, 1, 0);
   fprintf(stderr,"Position after move = 0x%08lx\n", position);
-  for (fieldidx = 0; fieldidx < gda_recordset_rowsize(rs); fieldidx++)
-    {
-      field = gda_recordset_field_idx(rs, fieldidx);
-      fprintf(stderr,"field->name = '%s'\n", gda_field_name(field));
-      fprintf(stderr,"field->actualSize = %d\n", gda_field_actual_size(field));
-      fprintf(stderr,"field->scale      = %d\n", gda_field_scale(field));
-      fprintf(stderr,"field->gdaType    = %s[%d]\n",
-	      gda_fieldtype_2_string(bfr, sizeof(bfr), field), gda_field_type(field));
-      
-      fprintf(stderr,"field->cType      = %d\n", gda_field_cType(field));
-      fprintf(stderr,"field->nativeType = %d\n", gda_field_nativeType(field));
-      value = field->real_value;
-      fprintf(stderr,"Value: is_null    = %d\n", gda_field_isnull(field));
-      fprintf(stderr,"       gdatype    = %d\n", value->_u.v._d);
-      fprintf(stderr,"       value      = %s\n", gda_stringify_value(vbfr,
-								     sizeof(vbfr), field));
-      fprintf(stderr,"\n\n");
-    }
+  if (position != GDA_RECORDSET_INVALID_POSITION)
+    for (fieldidx = 0; fieldidx < gda_recordset_rowsize(rs); fieldidx++)
+      {
+	field = gda_recordset_field_idx(rs, fieldidx);
+	fprintf(stderr,"field->name = '%s'\n", gda_field_name(field));
+	fprintf(stderr,"field->gdaType    = %s[%d]\n",
+		gda_fieldtype_2_string(bfr, sizeof(bfr), field), gda_field_type(field));
+	fprintf(stderr,"field->cType      = %d\n", gda_field_cType(field));
+	fprintf(stderr,"field->nativeType = %d\n", gda_field_nativeType(field));
+	fprintf(stderr,"Value: is_null    = %d\n", gda_field_isnull(field));
+	if (gda_field_isnull(field))
+	  {
+	    fprintf(stderr," <NULL>\n");
+	    continue;
+	  }
+	value = field->real_value;
+	fprintf(stderr,"field->actualSize = %d\n", gda_field_actual_size(field));
+	fprintf(stderr,"field->scale      = %d\n", gda_field_scale(field));
+	
+	fprintf(stderr,"       gdatype    = %d\n", value->_u.v._d);
+	fprintf(stderr,"       value      = %s\n", gda_stringify_value(vbfr,
+								       sizeof(vbfr), field));
+	fprintf(stderr,"\n\n");
+      }
   
   if (gda_connection_close(cnc) < 0)
     {
